pub struct HEARTBEAT_DATA {
pub custom_mode: u32,
pub mavtype: MavType,
pub autopilot: MavAutopilot,
pub base_mode: MavModeFlag,
pub system_status: MavState,
pub mavlink_version: u8,
}dialect-common only.Expand description
The heartbeat message shows that a system or component is present and responding. The type and autopilot fields (along with the message component id), allow the receiving system to treat further messages from this system appropriately (e.g. by laying out the user interface based on the autopilot). This microservice is documented at https://mavlink.io/en/services/heartbeat.html.
ID: 0
Fields
custom_mode: u32A bitfield for use for autopilot-specific flags
mavtype: MavTypeVehicle or component type. For a flight controller component the vehicle type (quadrotor, helicopter, etc.). For other components the component type (e.g. camera, gimbal, etc.). This should be used in preference to component id for identifying the component type.
autopilot: MavAutopilotAutopilot type / class. Use MAV_AUTOPILOT_INVALID for components that are not flight controllers.
base_mode: MavModeFlagSystem mode bitmap.
system_status: MavStateSystem status flag.
mavlink_version: u8MAVLink version, not writable by user, gets added by protocol because of magic data type: uint8_t_mavlink_version
Implementations