pub struct MOUNT_ORIENTATION_DATA {
pub time_boot_ms: u32,
pub roll: f32,
pub pitch: f32,
pub yaw: f32,
pub yaw_absolute: f32,
}This message is being superseded by MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW. The message can still be used to communicate with legacy gimbals implementing it. See MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW (Superseded since 2020-01)
dialect-common only.Expand description
Orientation of a mount.
ID: 265
Fields
time_boot_ms: u32This message is being superseded by MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW. The message can still be used to communicate with legacy gimbals implementing it. See MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW (Superseded since 2020-01)
Timestamp (time since system boot).
roll: f32This message is being superseded by MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW. The message can still be used to communicate with legacy gimbals implementing it. See MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW (Superseded since 2020-01)
Roll in global frame (set to NaN for invalid).
pitch: f32This message is being superseded by MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW. The message can still be used to communicate with legacy gimbals implementing it. See MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW (Superseded since 2020-01)
Pitch in global frame (set to NaN for invalid).
yaw: f32This message is being superseded by MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW. The message can still be used to communicate with legacy gimbals implementing it. See MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW (Superseded since 2020-01)
Yaw relative to vehicle (set to NaN for invalid).
yaw_absolute: f32This message is being superseded by MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW. The message can still be used to communicate with legacy gimbals implementing it. See MAV_CMD_DO_GIMBAL_MANAGER_PITCHYAW (Superseded since 2020-01)
Yaw in absolute frame relative to Earthโs North, north is 0 (set to NaN for invalid).
Implementations